@@ -1,6 +1,6 @@
 package Elastic::Model::Role::Index;
 {
-  $Elastic::Model::Role::Index::VERSION = '0.23';
+  $Elastic::Model::Role::Index::VERSION = '0.24';
 }
 
 use Moose::Role;
@@ -120,6 +120,7 @@ sub is_index {
 sub update_mapping {
 #===================================
     my $self     = shift;
+    my %args     = ref $_[-1] eq 'HASH' ? %{ pop() } : ();
     my $mappings = $self->mappings(@_);
     my $es       = $self->es;
     my $name     = $self->name;
@@ -127,7 +128,8 @@ sub update_mapping {
         $es->put_mapping(
             index   => $name,
             type    => $type,
-            mapping => $mappings->{$type}
+            mapping => $mappings->{$type},
+            %args,
         );
     }
     return $self;
@@ -137,9 +139,10 @@ sub update_mapping {
 sub delete_mapping {
 #===================================
     my $self = shift;
+    my %args = ref $_[-1] eq 'HASH' ? %{ pop() } : ();
     my $es   = $self->es;
     my $name = $self->name;
-    $es->delete_mapping( index => $name, type => $_ ) for @_;
+    $es->delete_mapping( index => $name, type => $_, %args ) for @_;
     return $self;
 }
 
@@ -155,7 +158,7 @@ Elastic::Model::Role::Index - Provides admin methods common to indices and alias
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -281,6 +284,7 @@ L</namespace>.
 
     $admin = $admin->update_mapping();
     $admin = $admin->update_mapping( @type_names );
+    $admin = $admin->update_mapping( @type_names, { ignore_conflicts=> 1 } );
 
 Type mappings B<cannot be changed> on an existing index, but they B<can be
 added to>.  L</update_mapping()> will generate a new type mapping from your
@@ -292,12 +296,19 @@ update all types known to the L</namespace>.
 
     $admin->update_mapping( 'user','post');
 
+Any optional args passed
+as a hashref as the final parameter will be passed to
+L<ElasticSearch/put_mapping()>
+
 =head2 delete_mapping();
 
     $admin = $admin->delete_mapping( @types );
+    $admin = $admin->delete_mapping( @types, { ignore_missing => 1 });
 
 Deletes the type mapping B<AND THE DOCUMENTS> for the listed types in the index
-(or the indices pointed to by alias) L</name>.
+(or the indices pointed to by alias) L</name>. Any optional args passed
+as a hashref as the final parameter will be passed to
+L<ElasticSearch/delete_mapping()>.
 
 =head2 exists()
 
@@ -346,7 +357,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Clinton Gormley.
+This software is copyright (c) 2013 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
